@@ -119,6 +119,25 @@ impl DiscreteCDF<u64, f64> for Binomial {
             beta::beta_reg((self.n - k) as f64, k as f64 + 1.0, 1.0 - self.p)
         }
     }
+
+    /// Calculates the survival function for the
+    /// binomial distribution at `x`
+    ///
+    /// # Formula
+    ///
+    /// ```ignore
+    /// I_(p)(x + 1, n - x)
+    /// ```
+    ///
+    /// where `I_(x)(a, b)` is the regularized incomplete beta function
+    fn sf(&self, x: u64) -> f64 {
+        if x >= self.n {
+            0.0
+        } else {
+            let k = x;
+            beta::beta_reg(k as f64 + 1.0, (self.n - k) as f64, self.p)
+        }
+    }
 }
 
 impl Min<u64> for Binomial {
@@ -299,7 +318,7 @@ impl Discrete<u64, f64> for Binomial {
 }
 
 #[rustfmt::skip]
-#[cfg(test)]
+#[cfg(all(test, feature = "nightly"))]
 mod tests {
     use std::fmt::Debug;
     use crate::statistics::*;
@@ -337,6 +356,7 @@ mod tests {
               F: Fn(Binomial) -> T
     {
         let x = get_value(p, n, eval);
+        println!("{} {} {:?}", p, n, expected);
         assert_eq!(expected, x);
     }
 
@@ -504,12 +524,47 @@ mod tests {
         test_case(1.0, 10, 1.0, cdf(10));
     }
 
+    #[test]
+    fn test_sf() {
+        let sf = |arg: u64| move |x: Binomial| x.sf(arg);
+        test_case(0.0, 1, 0.0, sf(0));
+        test_case(0.0, 1, 0.0, sf(1));
+        test_case(0.0, 3, 0.0, sf(0));
+        test_case(0.0, 3, 0.0, sf(1));
+        test_case(0.0, 3, 0.0, sf(3));
+        test_case(0.0, 10, 0.0, sf(0));
+        test_case(0.0, 10, 0.0, sf(1));
+        test_case(0.0, 10, 0.0, sf(10));
+        test_almost(0.3, 1, 0.3, 1e-15, sf(0));
+        test_case(0.3, 1, 0.0, sf(1));
+        test_almost(0.3, 3, 0.657, 1e-14, sf(0));
+        test_almost(0.3, 3, 0.216, 1e-15, sf(1));
+        test_case(0.3, 3, 0.0, sf(3));
+        test_almost(0.3, 10, 0.9717524751000001, 1e-16, sf(0));
+        test_almost(0.3, 10, 0.850691654100002, 1e-14, sf(1));
+        test_case(0.3, 10, 0.0, sf(10));
+        test_case(1.0, 1, 1.0, sf(0));
+        test_case(1.0, 1, 0.0, sf(1));
+        test_case(1.0, 3, 1.0, sf(0));
+        test_case(1.0, 3, 1.0, sf(1));
+        test_case(1.0, 3, 0.0, sf(3));
+        test_case(1.0, 10, 1.0, sf(0));
+        test_case(1.0, 10, 1.0, sf(1));
+        test_case(1.0, 10, 0.0, sf(10));
+    }
+
     #[test]
     fn test_cdf_upper_bound() {
         let cdf = |arg: u64| move |x: Binomial| x.cdf(arg);
         test_case(0.5, 3, 1.0, cdf(5));
     }
 
+    #[test]
+    fn test_sf_upper_bound() {
+        let sf = |arg: u64| move |x: Binomial| x.sf(arg);
+        test_case(0.5, 3, 0.0, sf(5));
+    }
+
     #[test]
     fn test_discrete() {
         test::check_discrete_distribution(&try_create(0.3, 5), 5);
