@@ -148,6 +148,9 @@ impl DiscreteCDF<u64, f64> for Hypergeometric {
     /// and `p_F_q` is the [generalized hypergeometric
     /// function](https://en.wikipedia.
     /// org/wiki/Generalized_hypergeometric_function)
+    ///
+    /// Calculated as a discrete integral over the probability mass
+    /// function evaluated from 0..k+1
     fn cdf(&self, x: u64) -> f64 {
         if x < self.min() {
             0.0
@@ -164,6 +167,40 @@ impl DiscreteCDF<u64, f64> for Hypergeometric {
             })
         }
     }
+
+    /// Calculates the survival function for the hypergeometric
+    /// distribution at `x`
+    ///
+    /// # Formula
+    ///
+    /// ```ignore
+    /// 1 - ((n choose k+1) * (N-n choose K-k-1)) / (N choose K) * 3_F_2(1,
+    /// k+1-K, k+1-n; k+2, N+k+2-K-n; 1)
+    /// ```
+    ///
+    /// where `N` is population, `K` is successes, `n` is draws,
+    /// and `p_F_q` is the [generalized hypergeometric
+    /// function](https://en.wikipedia.
+    /// org/wiki/Generalized_hypergeometric_function)
+    ///
+    /// Calculated as a discrete integral over the probability mass
+    /// function evaluated from (k+1)..max
+    fn sf(&self, x: u64) -> f64 {
+        if x < self.min() {
+            1.0
+        } else if x >= self.max() {
+            0.0
+        } else {
+            let k = x;
+            let ln_denom = factorial::ln_binomial(self.population, self.draws);
+            (k + 1 .. self.max() + 1).fold(0.0, |acc, i| {
+                acc + (factorial::ln_binomial(self.successes, i)
+                    + factorial::ln_binomial(self.population - self.successes, self.draws - i)
+                    - ln_denom)
+                    .exp()
+            })
+        }
+    }
 }
 
 impl Min<u64> for Hypergeometric {
@@ -327,7 +364,7 @@ impl Discrete<u64, f64> for Hypergeometric {
 }
 
 #[rustfmt::skip]
-#[cfg(test)]
+#[cfg(all(test, feature = "nightly"))]
 mod tests {
     use std::fmt::Debug;
     use crate::statistics::*;
@@ -509,10 +546,20 @@ mod tests {
         test_almost(10, 5, 3, 0.5, 1e-15, cdf(1));
         test_almost(10, 5, 3, 11.0 / 12.0, 1e-14, cdf(2));
         test_almost(10000, 2, 9800, 199.0 / 499950.0, 1e-14, cdf(0));
-        test_almost(10000, 2, 9800, 199.0 / 499950.0, 1e-14, cdf(0));
         test_almost(10000, 2, 9800, 19799.0 / 499950.0, 1e-12, cdf(1));
     }
 
+    #[test]
+    fn test_sf() {
+        let sf = |arg: u64| move |x: Hypergeometric| x.sf(arg);
+        test_case(2, 1, 1, 0.5, sf(0));
+        test_almost(10, 1, 1, 0.1, 1e-14, sf(0));
+        test_almost(10, 5, 3, 0.5, 1e-15, sf(1));
+        test_almost(10, 5, 3, 1.0 / 12.0, 1e-14, sf(2));
+        test_almost(10000, 2, 9800, 499751. / 499950.0, 1e-10, sf(0));
+        test_almost(10000, 2, 9800, 480151. / 499950.0, 1e-10, sf(1));
+    }
+
     #[test]
     fn test_cdf_arg_too_big() {
         let cdf = |arg: u64| move |x: Hypergeometric| x.cdf(arg);
@@ -525,6 +572,18 @@ mod tests {
         test_case(2, 2, 2, 0.0, cdf(0));
     }
 
+    #[test]
+    fn test_sf_arg_too_big() {
+        let sf = |arg: u64| move |x: Hypergeometric| x.sf(arg);
+        test_case(0, 0, 0, 0.0, sf(0));
+    }
+
+    #[test]
+    fn test_sf_arg_too_small() {
+        let sf = |arg: u64| move |x: Hypergeometric| x.sf(arg);
+        test_case(2, 2, 2, 1.0, sf(0));
+    }
+
     #[test]
     fn test_discrete() {
         test::check_discrete_distribution(&try_create(5, 4, 3), 4);
