@@ -83,6 +83,36 @@ impl ContinuousCDF<f64, f64> for LogNormal {
             0.5 * erf::erfc((self.location - x.ln()) / (self.scale * f64::consts::SQRT_2))
         }
     }
+
+    /// Calculates the survival function for the log-normal
+    /// distribution at `x`
+    ///
+    /// # Formula
+    ///
+    /// ```ignore
+    /// (1 / 2) + (1 / 2) * erf(-(ln(x) - μ) / sqrt(2) * σ)
+    /// ```
+    ///
+    /// where `μ` is the location, `σ` is the scale, and `erf` is the
+    /// error function
+    ///
+    /// note that this calculates the complement due to flipping
+    /// the sign of the argument error function with respect to the cdf.
+    ///
+    /// the normal cdf Φ (and internal error function) as the following property:
+    /// ```ignore
+    ///  Φ(-x) + Φ(x) = 1
+    ///  Φ(-x)        = 1 - Φ(x) 
+    /// ```
+    fn sf(&self, x: f64) -> f64 {
+        if x <= 0.0 {
+            1.0
+        } else if x.is_infinite() {
+            0.0
+        } else {
+            0.5 * erf::erfc((x.ln() - self.location) / (self.scale * f64::consts::SQRT_2))
+        }
+    }
 }
 
 impl Min<f64> for LogNormal {
@@ -237,7 +267,7 @@ impl Continuous<f64, f64> for LogNormal {
 }
 
 #[rustfmt::skip]
-#[cfg(test)]
+#[cfg(all(test, feature = "nightly"))]
 mod tests {
     use crate::statistics::*;
     use crate::distribution::{ContinuousCDF, Continuous, LogNormal};
@@ -590,12 +620,36 @@ mod tests {
         test_almost(2.5, 2.5, 0.13802019192453118732001307556787218421918336849121, 1e-11, cdf(0.8));
     }
 
+    #[test]
+    fn test_sf() {
+        let sf = |arg: f64| move |x: LogNormal| x.sf(arg);
+
+        // Wolfram Alpha:: SurvivalFunction[ LogNormalDistribution(-0.1, 0.1), 0.1]
+        test_almost(-0.1, 0.1, 1.0, 1e-107, sf(0.1));
+
+        // Wolfram Alpha:: SurvivalFunction[ LogNormalDistribution(-0.1, 0.1), 0.8]
+        test_almost(-0.1, 0.1, 0.890919989231123, 1e-14, sf(0.8));
+
+        // Wolfram Alpha:: SurvivalFunction[LogNormalDistribution[1.5, 1], 0.8]
+        test_almost(1.5, 1.0, 0.957568715612642, 1e-14, sf(0.8));
+
+        // Wolfram Alpha:: SurvivalFunction[ LogNormalDistribution(2.5, 1.5), 0.1]
+        test_almost(2.5, 1.5, 0.9993169594777358, 1e-14, sf(0.1));
+    }
+
     #[test]
     fn test_neg_cdf() {
         let cdf = |arg: f64| move |x: LogNormal| x.cdf(arg);
         test_case(0.0, 1.0, 0.0, cdf(0.0));
     }
 
+
+    #[test]
+    fn test_neg_sf() {
+        let sf = |arg: f64| move |x: LogNormal| x.sf(arg);
+        test_case(0.0, 1.0, 1.0, sf(0.0));
+    }
+
     #[test]
     fn test_continuous() {
         test::check_continuous_distribution(&try_create(0.0, 0.25), 0.0, 10.0);
