@@ -113,6 +113,28 @@ impl ContinuousCDF<f64, f64> for Pareto {
             1.0 - (self.scale / x).powf(self.shape)
         }
     }
+
+    /// Calculates the survival function for the Pareto
+    /// distribution at `x`
+    ///
+    /// # Formula
+    ///
+    /// ```ignore
+    /// if x < x_m {
+    ///     1
+    /// } else {
+    ///     (x_m/x)^α
+    /// }
+    /// ```
+    ///
+    /// where `x_m` is the scale and `α` is the shape
+    fn sf(&self, x: f64) -> f64 {
+        if x < self.scale {
+            1.0
+        } else {
+            (self.scale / x).powf(self.shape)
+        }
+    }
 }
 
 impl Min<f64> for Pareto {
@@ -303,7 +325,7 @@ impl Continuous<f64, f64> for Pareto {
 }
 
 #[rustfmt::skip]
-#[cfg(test)]
+#[cfg(all(test, feature = "nightly"))]
 mod tests {
     use crate::statistics::*;
     use crate::distribution::{ContinuousCDF, Continuous, Pareto};
@@ -487,6 +509,19 @@ mod tests {
         test_case(1.0, 1.0, 1.0, cdf(f64::INFINITY));
     }
 
+    #[test]
+    fn test_sf() {
+        let sf = |arg: f64| move |x: Pareto| x.sf(arg);
+        test_case(0.1, 0.1, 1.0, sf(0.1));
+        test_case(1.0, 1.0, 1.0, sf(1.0));
+        test_case(5.0, 5.0, 1.0, sf(2.0));
+        test_almost(7.0, 7.0, 0.08235429999999999, 1e-14, sf(10.0));
+        test_almost(10.0, 10.0, 0.16150558288984573, 1e14, sf(12.0));
+        test_case(5.0, 1.0, 0.5, sf(10.0));
+        test_almost(3.0, 10.0, 0.0009765625, 1e-14, sf(6.0));
+        test_case(1.0, 1.0, 0.0, sf(f64::INFINITY));
+    }
+
     #[test]
     fn test_continuous() {
         test::check_continuous_distribution(&try_create(1.0, 10.0), 1.0, 10.0);
