@@ -85,12 +85,26 @@ impl DiscreteCDF<u64, f64> for Poisson {
     /// # Formula
     ///
     /// ```ignore
-    /// 1 - P(x + 1, λ)
+    /// P(x + 1, λ)
+    /// ```
+    ///
+    /// where `λ` is the rate and `P` is the upper regularized gamma function
+    fn cdf(&self, x: u64) -> f64 {
+        gamma::gamma_ur(x as f64 + 1.0, self.lambda)
+    }
+
+    /// Calculates the survival function for the poisson
+    /// distribution at `x`
+    ///
+    /// # Formula
+    ///
+    /// ```ignore
+    /// P(x + 1, λ)
     /// ```
     ///
     /// where `λ` is the rate and `P` is the lower regularized gamma function
-    fn cdf(&self, x: u64) -> f64 {
-        1.0 - gamma::gamma_lr(x as f64 + 1.0, self.lambda)
+    fn sf(&self, x: u64) -> f64 {
+        gamma::gamma_lr(x as f64 + 1.0, self.lambda)
     }
 }
 
@@ -280,7 +294,7 @@ pub fn sample_unchecked<R: Rng + ?Sized>(rng: &mut R, lambda: f64) -> f64 {
 }
 
 #[rustfmt::skip]
-#[cfg(test)]
+#[cfg(all(test, feature = "nightly"))]
 mod tests {
     use std::fmt::Debug;
     use crate::statistics::*;
@@ -443,6 +457,20 @@ mod tests {
         test_almost(10.8, 0.9961800769608090000000, 1e-15, cdf(20));
     }
 
+    #[test]
+    fn test_sf() {
+        let sf = |arg: u64| move |x: Poisson| x.sf(arg);
+        test_almost(1.5, 0.44217459962892536, 1e-15, sf(1));
+        test_almost(1.5, 0.0000005517532358246565, 1e-15, sf(10));
+        test_almost(1.5, 2.3372210700347092e-17, 1e-15, sf(20));
+        test_almost(5.4, 0.971093881967279, 1e-16, sf(1));
+        test_almost(5.4, 0.022513699310235582, 1e-15, sf(10));
+        test_almost(5.4, 0.0000002800071708975261, 1e-15, sf(20));
+        test_almost(10.8, 0.9997592858597482, 1e-16, sf(1));
+        test_almost(10.8, 0.5160307640044303, 1e-15, sf(10));
+        test_almost(10.8, 0.003819923039191422, 1e-15, sf(20));
+    }
+
     #[test]
     fn test_discrete() {
         test::check_discrete_distribution(&try_create(0.3), 10);
